Linux workstation

Fedora 43 native package

libusb1-devel-doc

Development files for libusb1

Packages / Fedora 43 / Unspecified / libusb1-devel-doc

[Source: libusb1]

Package: libusb1-devel-doc (1.0.30-1.fc43)

External Resources:

Homepage: [libusb.info]

Similar packages:

Development files for libusb1

This package contains API documentation for libusb1.

Other Packages Related to libusb1-devel-doc:

  • dep: [libusb1-devel] (= 1.0.30-1.fc43)

    Development files for libusb1

Download libusb1-devel-doc

ArchitecturePackage SizeInstalled SizeFiles
noarch242 KiB1.9 MiB[list of files]

Package file paths (69)

Paths come from the repository package-file index for the observed builds. They describe archive/package associations, not every file that will exist on a running system after maintainer scripts, alternatives, generated state, diversions, or installation choices.

  • /usr/share/doc/libusb1-devel-doc
  • /usr/share/doc/libusb1-devel-doc/api-1.0
  • /usr/share/doc/libusb1-devel-doc/api-1.0/annotated.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/classes.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/clipboard.js
  • /usr/share/doc/libusb1-devel-doc/api-1.0/deprecated.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/dir_6560186179ae86ab3fbed805e7cb86e4.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/doxygen_crawl.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/doxygen.css
  • /usr/share/doc/libusb1-devel-doc/api-1.0/doxygen.svg
  • /usr/share/doc/libusb1-devel-doc/api-1.0/dynsections.js
  • /usr/share/doc/libusb1-devel-doc/api-1.0/files.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/functions.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/functions_vars.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/group__libusb__asyncio.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/group__libusb__desc.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/group__libusb__dev.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/group__libusb__hotplug.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/group__libusb__lib.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/group__libusb__misc.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/group__libusb__poll.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/group__libusb__syncio.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/index.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/jquery.js
  • /usr/share/doc/libusb1-devel-doc/api-1.0/libusb_8h_source.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/libusb_api.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/libusb_caveats.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/libusb_contexts.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/libusb_hotplug.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/libusb_io.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/libusb_mtasync.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/libusb_packetoverflow.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/libusb.png
  • /usr/share/doc/libusb1-devel-doc/api-1.0/menudata.js
  • /usr/share/doc/libusb1-devel-doc/api-1.0/menu.js
  • /usr/share/doc/libusb1-devel-doc/api-1.0/navtree.css
  • /usr/share/doc/libusb1-devel-doc/api-1.0/pages.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/structlibusb__bos__descriptor.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/structlibusb__bos__dev__capability__descriptor.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/structlibusb__config__descriptor.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/structlibusb__container__id__descriptor.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/structlibusb__control__setup.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/structlibusb__device__descriptor.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/structlibusb__endpoint__descriptor.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/structlibusb__init__option.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/structlibusb__interface__association__descriptor__array.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/structlibusb__interface__association__descriptor.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/structlibusb__interface__descriptor.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/structlibusb__interface.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/structlibusb__iso__packet__descriptor.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/structlibusb__platform__descriptor.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/structlibusb__pollfd.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/structlibusb__ss__endpoint__companion__descriptor.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/structlibusb__ssplus__sublink__attribute.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/structlibusb__ssplus__usb__device__capability__descriptor.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/structlibusb__ss__usb__device__capability__descriptor.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/structlibusb__transfer.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/structlibusb__usb__2__0__extension__descriptor.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/structlibusb__version.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/tabs.css
  • /usr/share/doc/libusb1-devel-doc/api-1.0/topics.html
  • /usr/share/doc/libusb1-devel-doc/dpfp.c
  • /usr/share/doc/libusb1-devel-doc/ezusb.c
  • /usr/share/doc/libusb1-devel-doc/fxload.c
  • /usr/share/doc/libusb1-devel-doc/hotplugtest.c
  • /usr/share/doc/libusb1-devel-doc/listdevs.c
  • /usr/share/doc/libusb1-devel-doc/sam3u_benchmark.c
  • /usr/share/doc/libusb1-devel-doc/testlibusb.c
  • /usr/share/doc/libusb1-devel-doc/xusb.c

Field source: Fedora 43 updates x86_64 revision 43-updates-x86_64:d59481a1758810a842f6aaef03eff437442211002d934e2d10266183c629137a

Use this package

OpenFactory can boot this operating system in a browser VM, or start a build that includes the native package name from this record.

Versions, suites, and repositories

Each row is recorded package-index metadata for one version, architecture, suite, and repository. Names, URLs, and sizes are source-reported; a link is a potentially mutable retrieval location, not an OpenFactory redistribution claim or proof that OpenFactory retained the artifact bytes.

VersionReleaseArchitectureRepositoryPackage sizeInstalled sizePublisher repository artifact
1.0.30-1.fc4343 / updatesnoarchFedora 43 · updates · x86_64242 KiB1.9 MiBPackages/l/libusb1-devel-doc-1.0.30-1.fc43.noarch.rpm
1.0.30-1.fc4343 / updatesnoarchFedora 43 · updates · aarch64242 KiB1.9 MiBPackages/l/libusb1-devel-doc-1.0.30-1.fc43.noarch.rpm
1.0.29-4.fc4343 / everythingnoarchFedora 43 · Everything · x86_64239 KiB1.8 MiBPackages/l/libusb1-devel-doc-1.0.29-4.fc43.noarch.rpm
1.0.29-4.fc4343 / everythingnoarchFedora 43 · Everything · aarch64239 KiB1.8 MiBPackages/l/libusb1-devel-doc-1.0.29-4.fc43.noarch.rpm

Field source: Fedora 43 updates x86_64 revision 43-updates-x86_64:d59481a1758810a842f6aaef03eff437442211002d934e2d10266183c629137a

Checksums and observation dates

For an APT source, signature verification authenticates the repository metadata chain and the Packages index containing this source-reported artifact digest. It does not certify package safety.

1.0.30-1.fc43 / noarchObserved Sep 1, 2026 to Sep 1, 2026

Verification status: Metadata observed; artifact bytes were not independently fetched or hashed by this catalog import. The digest below is source-reported.

Source-reported sha256: eaf16683efea4b24bc5aa68b3c2e00ea234cbe247cbc08e50bc48d88c5711729

After downloading that exact artifact, compare its bytes with the source-reported expected digest:

printf '%s %s\n' 'eaf16683efea4b24bc5aa68b3c2e00ea234cbe247cbc08e50bc48d88c5711729' 'libusb1-devel-doc-1.0.30-1.fc43.noarch.rpm' | sha256sum --check --strict -

A match establishes equality with the repository metadata value. It does not establish safety or catalog-side artifact retrieval.

Field source: Fedora 43 updates x86_64 revision 43-updates-x86_64:d59481a1758810a842f6aaef03eff437442211002d934e2d10266183c629137a

1.0.30-1.fc43 / noarchObserved Sep 1, 2026 to Sep 1, 2026

Verification status: Metadata observed; artifact bytes were not independently fetched or hashed by this catalog import. The digest below is source-reported.

Source-reported sha256: eaf16683efea4b24bc5aa68b3c2e00ea234cbe247cbc08e50bc48d88c5711729

After downloading that exact artifact, compare its bytes with the source-reported expected digest:

printf '%s %s\n' 'eaf16683efea4b24bc5aa68b3c2e00ea234cbe247cbc08e50bc48d88c5711729' 'libusb1-devel-doc-1.0.30-1.fc43.noarch.rpm' | sha256sum --check --strict -

A match establishes equality with the repository metadata value. It does not establish safety or catalog-side artifact retrieval.

Field source: Fedora 43 updates aarch64 revision 43-updates-aarch64:ac6921c749da1e864e0971122151b63bb17e427965b3d9f9312a07b49ff10cac

1.0.29-4.fc43 / noarchObserved Sep 1, 2026 to Sep 1, 2026

Verification status: Metadata observed; artifact bytes were not independently fetched or hashed by this catalog import. The digest below is source-reported.

Source-reported sha256: d3bda5815b55d8c8f3bc28bc6432dc3668f2d508b2ff31e42128e0d1426202bc

After downloading that exact artifact, compare its bytes with the source-reported expected digest:

printf '%s %s\n' 'd3bda5815b55d8c8f3bc28bc6432dc3668f2d508b2ff31e42128e0d1426202bc' 'libusb1-devel-doc-1.0.29-4.fc43.noarch.rpm' | sha256sum --check --strict -

A match establishes equality with the repository metadata value. It does not establish safety or catalog-side artifact retrieval.

Field source: Fedora 43 Everything x86_64 revision 43-everything-x86_64:eb1d8634a798b5cfcef64b0114711f431f2cd186b55cce902f1883a32c6ff4f2

1.0.29-4.fc43 / noarchObserved Sep 1, 2026 to Sep 1, 2026

Verification status: Metadata observed; artifact bytes were not independently fetched or hashed by this catalog import. The digest below is source-reported.

Source-reported sha256: d3bda5815b55d8c8f3bc28bc6432dc3668f2d508b2ff31e42128e0d1426202bc

After downloading that exact artifact, compare its bytes with the source-reported expected digest:

printf '%s %s\n' 'd3bda5815b55d8c8f3bc28bc6432dc3668f2d508b2ff31e42128e0d1426202bc' 'libusb1-devel-doc-1.0.29-4.fc43.noarch.rpm' | sha256sum --check --strict -

A match establishes equality with the repository metadata value. It does not establish safety or catalog-side artifact retrieval.

Field source: Fedora 43 Everything aarch64 revision 43-everything-aarch64:6431612747d987257399969298151d19cfe87ed26322be6987e7b00cd0ae66a2

Catalog record completeness

The completeness score measures metadata coverage, not software quality, security, compatibility, or suitability.

Summary and description
25/25
Artifact path and source digest
25/25
Dependency metadata
15/15
Package-file index
15/15
Homepage
5/5
License text
5/5
Source package or maintainer
10/10

Recorded total: 100/100

Field source: Fedora 43 Everything aarch64 revision 43-everything-aarch64:6431612747d987257399969298151d19cfe87ed26322be6987e7b00cd0ae66a2, Fedora 43 Everything x86_64 revision 43-everything-x86_64:eb1d8634a798b5cfcef64b0114711f431f2cd186b55cce902f1883a32c6ff4f2, Fedora 43 updates aarch64 revision 43-updates-aarch64:ac6921c749da1e864e0971122151b63bb17e427965b3d9f9312a07b49ff10cac, Fedora 43 updates x86_64 revision 43-updates-x86_64:d59481a1758810a842f6aaef03eff437442211002d934e2d10266183c629137a. The cross-OS mapping is catalog-derived from the source-reported homepage; it does not establish authorship or publisher identity

Sources and provenance

Field-source links above resolve here. Each source entry names the metadata publisher, trust tier, exact snapshot revision, signature result, and observation time; catalog-derived mappings are labeled separately.

  • Authoritative source; repository metadata signature verified, revision 43-everything-aarch64:6431612747d987257399969298151d19cfe87ed26322be6987e7b00cd0ae66a2

    Signature verification covers the configured repository metadata chain. It does not certify that the package is safe or suitable.

    Repository-signature verification record
    Signed-object SHA-256
    6c2a7b7225a6bd12acd5c95dcd0350a0a5929e195692ff68eb31db0ee6b9897b
    Signer fingerprint
    Not recorded
    Keyring revision
    RPM-GPG-KEY-fedora-43-primary
    SHA-256 2b1449a082d3264dda8e18369f04e9ac4163bf3f8cb530b0783dc2ab064a08ec
    Tool and policy
    1
    openfactory-software-catalog-signature-v1
    Verification time
    Sep 1, 2026
    Signed Release → package-index hash linkage

    Path: Not recorded
    Expected SHA-256: Not recorded
    Observed SHA-256: Not recorded
    Result: match verified

  • Authoritative source; repository metadata signature verified, revision 43-everything-x86_64:eb1d8634a798b5cfcef64b0114711f431f2cd186b55cce902f1883a32c6ff4f2

    Signature verification covers the configured repository metadata chain. It does not certify that the package is safe or suitable.

    Repository-signature verification record
    Signed-object SHA-256
    42c0002750de6066124693fff143f4854c1e29474d893f7e6a7616012d41338f
    Signer fingerprint
    Not recorded
    Keyring revision
    RPM-GPG-KEY-fedora-43-primary
    SHA-256 2b1449a082d3264dda8e18369f04e9ac4163bf3f8cb530b0783dc2ab064a08ec
    Tool and policy
    1
    openfactory-software-catalog-signature-v1
    Verification time
    Sep 1, 2026
    Signed Release → package-index hash linkage

    Path: Not recorded
    Expected SHA-256: Not recorded
    Observed SHA-256: Not recorded
    Result: match verified

  • Authoritative source; repository metadata signature verified, revision 43-updates-aarch64:ac6921c749da1e864e0971122151b63bb17e427965b3d9f9312a07b49ff10cac

    Signature verification covers the configured repository metadata chain. It does not certify that the package is safe or suitable.

    Repository-signature verification record
    Signed-object SHA-256
    0af1807dead0a1d28599a942743e244fe57da21cf6a935b3e4155f4a3f1070a1
    Signer fingerprint
    Not recorded
    Keyring revision
    RPM-GPG-KEY-fedora-43-primary
    SHA-256 2b1449a082d3264dda8e18369f04e9ac4163bf3f8cb530b0783dc2ab064a08ec
    Tool and policy
    1
    openfactory-software-catalog-signature-v1
    Verification time
    Sep 1, 2026
    Signed Release → package-index hash linkage

    Path: Not recorded
    Expected SHA-256: Not recorded
    Observed SHA-256: Not recorded
    Result: match verified

  • Authoritative source; repository metadata signature verified, revision 43-updates-x86_64:d59481a1758810a842f6aaef03eff437442211002d934e2d10266183c629137a

    Signature verification covers the configured repository metadata chain. It does not certify that the package is safe or suitable.

    Repository-signature verification record
    Signed-object SHA-256
    3ae5fecc3db8c7b4ce0cf54a8ea572ed4694e7e132e201c2f6ab6570259d1061
    Signer fingerprint
    Not recorded
    Keyring revision
    RPM-GPG-KEY-fedora-43-primary
    SHA-256 2b1449a082d3264dda8e18369f04e9ac4163bf3f8cb530b0783dc2ab064a08ec
    Tool and policy
    1
    openfactory-software-catalog-signature-v1
    Verification time
    Sep 1, 2026
    Signed Release → package-index hash linkage

    Path: Not recorded
    Expected SHA-256: Not recorded
    Observed SHA-256: Not recorded
    Result: match verified

libusb1-devel-doc Package for Fedora 43 | OpenFactory